function [err,msg]=AddDependenciesTasks(TasksNames,..//Имена задач
                                        TasksDependenciesTableFileName,..//Имя файла таблицы зависимостей задач
                                        TasksDatasEnabled,..//Имеющиеся данные для задач
                                        ProjectName,..//Имя проекта
                                        errPrintMsg..//Необходимость печати сообщений об ошибках
                                        )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 3 then
        error('The function AddDependenciesTasks takes 3, 4 or 5 arguments');
    end
    select nArg
    case 3 then
        ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        errPrintMsg = %t;//По умолчанию печатаем сообщение об ошибках
    case 4 then
        if type(ProjectName) == 4 then
            errPrintMsg = ProjectName;
            ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
        end
    end
    
    //Формируем полное имя файла группы задач
    [fullTasksGroupNameFileName,..
     err,msg] = GetFullServiceDataFileName(GetTasksGroupName() + '.csv',..
                                           ProjectName,errPrintMsg);
    if (err ~= 0) && (~errPrintMsg) then
        return;
    end
    
    //Сохраняем задачи в файл группы задач
    TasksNames = matrix(basename(TasksNames),1,-1);
    try
        csvWrite(TasksNames,fullTasksGroupNameFileName,',');
    catch
        err = 1;
        msg = lasterror();
        if errPrintMsg then
            error(msg);
        else
            return;
        end
    end
    
    //Считываем файл таблицы зависимостей задач
    try
        TasksDependenciesTable = csvRead(TasksDependenciesTableFileName,',',..
                                         '.','string');
    catch
        err = 1;
        msg = lasterror();
        if errPrintMsg then
            error(msg);
        else
            return;
        end
    end
    tTasksNames = TasksDependenciesTable(1,:);//Имена задач
    tTasksDatasNames = TasksDependenciesTable(2,:);//Имена данных для задач
    
    //Формируем для каждой задачи файлы зависимостей и разрешимостей
    for TaskName=TasksNames
        //Формируем полное имя файла задачи
        fullTaskNameFile = GetFullServiceDataFileName('d_' + TaskName + '.csv',..
                                                      ProjectName,errPrintMsg);
        
        //Формируем содержимое файла задач
        indTask = (tTasksNames == TaskName);//Индекс задачи в таблице зависимостей задач
        if or(indTask) then
            //Парсим данные для задачи
            mTasksDatasNames = csvTextScan(tTasksDatasNames(indTask),',','.','string');
            mTasksDatasNames = stripblanks(mTasksDatasNames);
            
            //Формируем индексы доступности данных
            TasksDatasEnabledInd = zeros(mTasksDatasNames);//Индексы доступности
            TasksDatasInd = (members(mTasksDatasNames,TasksDatasEnabled) > 0);
            TasksDatasEnabledInd(TasksDatasInd) = 1;
            
            //Формируем строки записи
            if and(TasksDatasEnabledInd > 0) then
                csvTaskDependence = [mTasksDatasNames;..
                                     string(zeros(TasksDatasEnabledInd))];
                csvTaskDependence = [csvTaskDependence,['Enabled';'1']];
            else
                csvTaskDependence = [mTasksDatasNames;..
                                     string(TasksDatasEnabledInd)];
                csvTaskDependence = [csvTaskDependence,['Enabled';'0']];
            end
        else
            csvTaskDependence = ['Enabled';'1'];
        end
        
        //Записываем файл задач
        try
            csvWrite(csvTaskDependence,fullTaskNameFile,',');
        catch
            err = 1;
            msg = lasterror();
            if errPrintMsg then
                error(msg);
            else
                return;
            end
        end 
    end
endfunction
